pub struct MatchStatus {
pub in_main_path: bool,
}Expand description
the status of matching.
contains variables / flags affecting the matching operation.
Fields
in_main_path: boolwhether the failure of the current match halt the overall matching.
set to true in all expressions except in negation, peak, or, and loop iterations after minimuim.
used to provide better error messages when needed.